@@ -148,7 +148,7 @@ def _buildDictionary(componentOption, hubName):
 	data = (componentOption)
 	paramsString = db.query_selectscalar(sql, data)
 	
-	if hubzero.utilities.misc.JOOMLA_25 and parmsString.startswith('{'):
+	if hubzero.utilities.misc.JOOMLA_25 and paramsString.startswith('{'):
 		try:
 			parmsDict = json.loads(paramsString)
 			return parmsDict
