@@ -264,9 +264,12 @@ def _insert_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, username,
 	sql += "`proxyPassword`, `proxyUidNumber`, `givenName`, `middleName`, `surname`, `picture`, `vip`, `public`, `params`, `note`, `shadowExpire`) "
 	sql += "VALUES (" + '%s,'*37 + "%s );" 
 
+	# this is a hack, @TODO: something less hackish would be good here
+	tou = 1
+
 	data = (uidNumber, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
 		    '/usr/lib/sftp-server', pw, gid, '', '', '', '', '', '', '', 
-		    0, 0, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
+		    0, tou, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
 		    '', '', fname, mname, lname, '', 0, 0, '', '', None)
 	db.query_rowcount(sql, data)
 
@@ -457,7 +460,10 @@ def addhubuser(hubname,
 		uidNumber = _insert_jos_users(db, uidNumber, fullName, username, email, pw, joomlagidNumber)
 
 		if hubzero.utilities.misc.JOOMLA_25:
-			_insert_jos_user_usergroup_map(db, uidNumber, 2)
+			if (joomlagidNumber == 25):
+				_insert_jos_user_usergroup_map(db, uidNumber, 8)
+			else:
+				_insert_jos_user_usergroup_map(db, uidNumber, 2)
 		else:
 	  		aroID = _insert_jos_core_acl_aro(db, uidNumber, fullName)
 			_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
